diff --git a/docs/images/script-demo.svg b/docs/images/script-demo.svg
index a5a8685..9495363 100644
--- a/docs/images/script-demo.svg
+++ b/docs/images/script-demo.svg
@@ -1 +1 @@
-
+##CreatingVPNconfiguration...##VPNcredentialsnotsetbyuser.GeneratingrandomPSKandpassword...##Installingpackagesrequiredforsetup...++apt-get+apt-get-yqq+apt-get-yqqupdate+apt-get-yqqinstall+apt-get-yqqinstallwgetdnsutilsopenssliptablesiproute2gawkgrepsednet-tools##TryingtoautodiscoverIPofthisserver...##InstallingpackagesrequiredfortheVPN...+apt-get-yqqinstalllibnss3-devlibnspr4-devpkg-configlibpam0g-devlibcap-ng-devlibcap-ng-utilslibselinux1-devlibcurl4-nss-devflexbisongccmakelibnss3-toolslibevent-devlibsystemd-devuuid-runtimepppxl2tpd##InstallingFail2BantoprotectSSH...+apt-get-yqqinstallfail2ban##DownloadingIKEv2script...+wget+wget-t+wget-t3+wget-t3-T+wget-t3-T30+wget-t3-T30-q+wget-t3-T30-q-O+wget-t3-T30-q-Oikev2.shhttps://github.com/hwdsl2/setup-ipsec-vpn/raw/master/extras/ikev2setup.sh##DownloadingLibreswan...+wget-t3-T30-q-Olibreswan-4.4.tar.gzhttps://github.com/libreswan/libreswan/archive/v4.4.tar.gz##CompilingandinstallingLibreswan,pleasewait...+make+make-j2-sbase+make-sinstall-base##VPNsetupinprogress...Pleasebepatient.##Updatingsysctlsettings...##UpdatingIPTablesrules...##Enablingservicesonboot...##Startingservices...================================================IPsecVPNserverisnowreadyforuse!ConnecttoyournewVPNwiththesedetails:ServerIP:192.0.2.1IPsecPSK:DEMO_ONLY_DO_NOT_USEUsername:vpnuserPassword:DEMO_ONLY_DO_NOT_USEWritethesedown.You'llneedthemtoconnect!Importantnotes:vpnsetup.net/notesVPNclientsetup:vpnsetup.net/clientsIKEv2guide:vpnsetup.net/ikev2##StartingIKEv2setupinautomode,usingdefaultoptions.IKEv2setupsuccessful.DetailsforIKEv2mode:VPNserveraddress:192.0.2.1VPNclientname:vpnclientClientconfigurationisavailableat:/root/vpnclient.p12(forWindows&Linux)/root/vpnclient.sswan(forAndroid)/root/vpnclient.mobileconfig(foriOS&macOS)*IMPORTANT*Passwordforclientconfigfiles:DEMO_ONLY_DO_NOT_USEWritethisdown,you'llneeditforimport!Nextsteps:ConfigureIKEv2VPNclients.See:https://vpnsetup.net/ikev2+apt-get-yqqinstallwget+apt-get-yqqinstallwgetdnsutils+apt-get-yqqinstallwgetdnsutilsopenssl+apt-get-yqqinstallwgetdnsutilsopenssliptables+apt-get-yqqinstallwgetdnsutilsopenssliptablesiproute2+apt-get-yqqinstallwgetdnsutilsopenssliptablesiproute2gawk+apt-get-yqqinstallwgetdnsutilsopenssliptablesiproute2gawkgrep+apt-get-yqqinstallwgetdnsutilsopenssliptablesiproute2gawkgrepsed+apt-get-yqqinstalllibnss3-dev+apt-get-yqqinstalllibnss3-devlibnspr4-dev+apt-get-yqqinstalllibnss3-devlibnspr4-devpkg-config+apt-get-yqqinstalllibnss3-devlibnspr4-devpkg-configlibpam0g-dev+apt-get-yqqinstalllibnss3-devlibnspr4-devpkg-configlibpam0g-devlibcap-ng-dev+apt-get-yqqinstalllibnss3-devlibnspr4-devpkg-configlibpam0g-devlibcap-ng-devlibcap-ng-utilsx1-devx1-devlibcurl4-nss-devx1-devlibcurl4-nss-devflexx1-devlibcurl4-nss-devflexbisonx1-devlibcurl4-nss-devflexbisongccx1-devlibcurl4-nss-devflexbisongccmakex1-devlibcurl4-nss-devflexbisongccmakelibnss3-toolsx1-devlibcurl4-nss-devflexbisongccmakelibnss3-toolslibevent-dev+wget-t3-T30-q-Oikev2.sh+wget-t3-T30-q-Olibreswan-4.4.tar.gz+make-j2+make-j2-s+make-s##CheckingforMOBIKEsupport...notavailable##GeneratingCAandservercertificates...##Generatingclientcertificate...##Creatingclientconfiguration...##AddinganewIKEv2connection...##RestartingIPsecservice...
diff --git a/extras/add_vpn_user.sh b/extras/add_vpn_user.sh
index a0bbb85..74701f0 100755
--- a/extras/add_vpn_user.sh
+++ b/extras/add_vpn_user.sh
@@ -90,8 +90,8 @@ Password: $VPN_PASSWORD
Write these down. You'll need them to connect!
-Important notes: vpnsetup.net/notes
-Setup VPN clients: vpnsetup.net/clients
+Important notes: vpnsetup.net/notes
+VPN client setup: vpnsetup.net/clients
================================================
diff --git a/extras/quickstart.sh b/extras/quickstart.sh
index f056755..971f145 100755
--- a/extras/quickstart.sh
+++ b/extras/quickstart.sh
@@ -27,9 +27,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
-# Important notes: vpnsetup.net/notes
-# Setup VPN clients: vpnsetup.net/clients
-# IKEv2 guide: vpnsetup.net/ikev2
+# Important notes: vpnsetup.net/notes
+# VPN client setup: vpnsetup.net/clients
# =====================================================
diff --git a/extras/update_vpn_users.sh b/extras/update_vpn_users.sh
index 0714914..cfbfeec 100755
--- a/extras/update_vpn_users.sh
+++ b/extras/update_vpn_users.sh
@@ -107,8 +107,8 @@ cat <<'EOF'
Write these down. You'll need them to connect!
-Important notes: vpnsetup.net/notes
-Setup VPN clients: vpnsetup.net/clients
+Important notes: vpnsetup.net/notes
+VPN client setup: vpnsetup.net/clients
==================================================
diff --git a/vpnsetup.sh b/vpnsetup.sh
index f056755..971f145 100755
--- a/vpnsetup.sh
+++ b/vpnsetup.sh
@@ -27,9 +27,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
-# Important notes: vpnsetup.net/notes
-# Setup VPN clients: vpnsetup.net/clients
-# IKEv2 guide: vpnsetup.net/ikev2
+# Important notes: vpnsetup.net/notes
+# VPN client setup: vpnsetup.net/clients
# =====================================================
diff --git a/vpnsetup_alpine.sh b/vpnsetup_alpine.sh
index dc37a04..2b879de 100755
--- a/vpnsetup_alpine.sh
+++ b/vpnsetup_alpine.sh
@@ -26,9 +26,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
# Important notes: vpnsetup.net/notes
# Setup VPN clients: vpnsetup.net/clients
# IKEv2 guide: vpnsetup.net/ikev2
# =====================================================
@@ -530,9 +529,8 @@ Password: $VPN_PASSWORD
Write these down. You'll need them to connect!
-Important notes: vpnsetup.net/notes
-Setup VPN clients: vpnsetup.net/clients
-IKEv2 guide: vpnsetup.net/ikev2
+Important notes: vpnsetup.net/notes
+VPN client setup: vpnsetup.net/clients
================================================
@@ -26,9 +26,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
-# Important notes: vpnsetup.net/notes
-# Setup VPN clients: vpnsetup.net/clients
-# IKEv2 guide: vpnsetup.net/ikev2
+# Important notes: vpnsetup.net/notes
+# VPN client setup: vpnsetup.net/clients
# =====================================================
diff --git a/vpnsetup_amzn.sh b/vpnsetup_amzn.sh
index aae0fb8..39ba3d9 100755
--- a/vpnsetup_amzn.sh
+++ b/vpnsetup_amzn.sh
@@ -26,9 +26,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
# Important notes: vpnsetup.net/notes
# Setup VPN clients: vpnsetup.net/clients
# IKEv2 guide: vpnsetup.net/ikev2
# =====================================================
@@ -546,9 +545,8 @@ Password: $VPN_PASSWORD
Write these down. You'll need them to connect!
-Important notes: vpnsetup.net/notes
-Setup VPN clients: vpnsetup.net/clients
-IKEv2 guide: vpnsetup.net/ikev2
+Important notes: vpnsetup.net/notes
+VPN client setup: vpnsetup.net/clients
================================================
@@ -26,9 +26,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
-# Important notes: vpnsetup.net/notes
-# Setup VPN clients: vpnsetup.net/clients
-# IKEv2 guide: vpnsetup.net/ikev2
+# Important notes: vpnsetup.net/notes
+# VPN client setup: vpnsetup.net/clients
# =====================================================
diff --git a/vpnsetup_centos.sh b/vpnsetup_centos.sh
index a2c5196..44a2f3c 100755
--- a/vpnsetup_centos.sh
+++ b/vpnsetup_centos.sh
@@ -28,9 +28,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
# Important notes: vpnsetup.net/notes
# Setup VPN clients: vpnsetup.net/clients
# IKEv2 guide: vpnsetup.net/ikev2
# =====================================================
@@ -686,9 +685,8 @@ Password: $VPN_PASSWORD
Write these down. You'll need them to connect!
-Important notes: vpnsetup.net/notes
-Setup VPN clients: vpnsetup.net/clients
-IKEv2 guide: vpnsetup.net/ikev2
+Important notes: vpnsetup.net/notes
+VPN client setup: vpnsetup.net/clients
================================================
@@ -28,9 +28,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
-# Important notes: vpnsetup.net/notes
-# Setup VPN clients: vpnsetup.net/clients
-# IKEv2 guide: vpnsetup.net/ikev2
+# Important notes: vpnsetup.net/notes
+# VPN client setup: vpnsetup.net/clients
# =====================================================
diff --git a/vpnsetup_ubuntu.sh b/vpnsetup_ubuntu.sh
index c8c2b4d..2e813c1 100755
--- a/vpnsetup_ubuntu.sh
+++ b/vpnsetup_ubuntu.sh
@@ -27,9 +27,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
# Important notes: vpnsetup.net/notes
# Setup VPN clients: vpnsetup.net/clients
# IKEv2 guide: vpnsetup.net/ikev2
# =====================================================
@@ -648,9 +647,8 @@ Password: $VPN_PASSWORD
Write these down. You'll need them to connect!
-Important notes: vpnsetup.net/notes
-Setup VPN clients: vpnsetup.net/clients
-IKEv2 guide: vpnsetup.net/ikev2
+Important notes: vpnsetup.net/notes
+VPN client setup: vpnsetup.net/clients
================================================
@@ -27,9 +27,8 @@ YOUR_IPSEC_PSK=''
YOUR_USERNAME=''
YOUR_PASSWORD=''
-# Important notes: vpnsetup.net/notes
-# Setup VPN clients: vpnsetup.net/clients
-# IKEv2 guide: vpnsetup.net/ikev2
+# Important notes: vpnsetup.net/notes
+# VPN client setup: vpnsetup.net/clients
# =====================================================